# itkwasm

Python interface to [itk-wasm](https://wasm.itk.org) WebAssembly modules.

For more information, see the [project documentation](https://itkwasm.readthedocs.io).

## Development

Thank you for contributing a pull request!

**Welcome to the ITK community!**

We are glad you are here and appreciate your contribution. Please keep in mind our [community participation guidelines](https://github.com/InsightSoftwareConsortium/ITK/blob/main/CODE_OF_CONDUCT.md).

```
git clone https://github.com/InsightSoftwareConsortium/itk-wasm
cd itk-wasm/packages/core/python/itkwasm
pip install hatch
hatch run download-pyodide
hatch run test
```
